@@ -17,6 +17,14 @@ class EntryFileNotFoundException(Error):
     """raised if the entry file, with name of 'score.py', is not found in the base directory"""
     pass
 
+class AppFileAlreadyExistsException(Error):
+    """raised if a file by the name of app.py is found in the target directory"""
+    pass
+
+class DockerfileAlreadyExistsException(Error):
+    """raised if a dockerfile ('dockerfile') already exists in the target directory."""
+    pass
+
 class DockerBuilder():
     """
     Prepares required assets and builds a  docker image, with web service, to serve a machine learning model.
@@ -45,6 +53,10 @@ class DockerBuilder():
             raise NoModelFileException("You must have a serialized model file.")
         if not os.path.exists(self.entry_file):
             raise EntryFileNotFoundException("An entry file named 'score.py' must be included in the base directory.")
+        if os.path.exists("app.py"):
+            raise AppFileAlreadyExistsException("There is already a file by the name of 'app.py' in your target directory. Please delete or rename this file, then run the command again.")
+        if os.path.exists('dockerfile'):
+            raise DockerfileAlreadyExistsException("There is already a file by the name of 'dockerfile' in the target directory. Please delete this file and try the command again")
 
     def create_api(self):
         """this builds the api file"""
@@ -74,7 +86,8 @@ if __name__ == '__main__':
         Params:
         imagename (string) --> the name you wish to use for the newly-created container image
         """
-        commands = ['FROM ubuntu:16.04' + "\n",
+        commands = ['FROM alpine' + "\n",
+        'FROM python:3.7' + '\n',
         "RUN apt-get update -y && apt-get install -y python-pip python-dev python-jinja2 python-flask" + "\n",
         "COPY ./requirements.txt /app/requirements.txt" + "\n",
         "WORKDIR /app" + "\n",
@@ -117,4 +130,4 @@ if __name__ == '__main__':
         print("ml_unleash")
         print('To compile and build your invokable REST endpoint inside of a docker container, use the method "do_all"')
         print('To complete each step individually, follow the flow of "prepare" -> "create_api" -> "build_image" -> "cleanup"')
-        print('To run the image, use the method "run", and pass the desired port (or leave blank to use localhost:5000)')
\ No newline at end of file
+        print('To run the image, use the method "run", and pass the desired port (or leave blank to use localhost:5000)')
